"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.rollupConfigStarterCreator = void 0;
const creator_utils_1 = require("@knapsack/creator-utils");
const { pkg } = (0, creator_utils_1.findUpPkgJson)(__dirname);
exports.rollupConfigStarterCreator = (0, creator_utils_1.createCreator)({
    id: 'rollup-config-starter',
    getQuestions: async () => ({}),
    getTasks: async ({ answers, config: { dest } }) => {
        return [
            {
                title: 'Add rollup.config.js',
                task: async () => {
                    return creator_utils_1.tasks.addFile({
                        destination: './rollup.config.js',
                        handlePriorFile: 'overwrite',
                        contents: `
import { createWebRollupConfig } from '${pkg.name}';
import { join } from 'path';

const config = createWebRollupConfig({
  input: {
    main: join(__dirname, './src/index.ts'),
  },
  distDir: join(__dirname, './dist'),
});

export default config;
        `,
                    });
                },
            },
            {
                title: 'Update package.json',
                task: async () => {
                    await creator_utils_1.tasks.updatePkgJson({
                        dir: dest,
                        pkg: {
                            scripts: {
                                build: 'rollup --config ./rollup.config.js',
                            },
                            devDependencies: {
                                [pkg.name]: pkg.version,
                                rollup: pkg.dependencies.rollup,
                            },
                        },
                    });
                },
            },
        ];
    },
});
//# sourceMappingURL=rollup-config-starter-creator.js.map