"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const promises_1 = __importDefault(require("fs/promises"));
const cheerio_1 = __importDefault(require("cheerio"));
const svgo_1 = require("svgo");
function isOptimizedSvg(result) {
    return typeof result.data === 'string';
}
function createSymbol(code, id) {
    const markup = cheerio_1.default.load(code, { xmlMode: true });
    const svgMarkup = markup('svg');
    const fill = svgMarkup.attr('fill');
    markup('svg').replaceWith('<symbol/>');
    markup('symbol')
        .attr('xmlns', 'http://www.w3.org/2000/svg')
        .attr('id', id)
        .attr('fill', fill)
        .attr('viewBox', svgMarkup.attr('viewBox'))
        .append(svgMarkup.children());
    return markup.xml('symbol');
}
function createSprite(symbols) {
    return `<svg xmlns="http://www.w3.org/2000/svg">${symbols.join('')}</svg>`;
}
function svgSprite({ minify = true, outputFolder, }) {
    if (!outputFolder) {
        throw new Error('"outputFolder" must be set');
    }
    const loadedSvgs = new Set();
    const convertedSvgs = new Map();
    return {
        name: 'svg-sprite',
        load(id) {
            if (id.endsWith('.svg')) {
                loadedSvgs.add(id);
            }
            return null;
        },
        transform(code, id) {
            if (!id.endsWith('.svg')) {
                return null;
            }
            const filename = (0, path_1.basename)(id, '.svg');
            convertedSvgs.set(id, createSymbol(code, filename));
            return {
                code: '',
            };
        },
        async writeBundle() {
            if (loadedSvgs.size) {
                const symbols = [...loadedSvgs.values()].map((id) => convertedSvgs.get(id));
                const x = (0, svgo_1.optimize)(createSprite(symbols), {
                    js2svg: {
                        pretty: !minify,
                        indent: 2,
                    },
                    plugins: ['removeDimensions', 'removeTitle'],
                });
                if (!isOptimizedSvg(x)) {
                    throw new Error(x.error);
                }
                await promises_1.default.writeFile((0, path_1.join)(outputFolder, `sprites.svg`), x.data, {
                    encoding: 'utf8',
                });
                loadedSvgs.clear();
            }
        },
    };
}
exports.default = svgSprite;
//# sourceMappingURL=rollup-plugin-svg-sprite.js.map